@@ -228,6 +228,22 @@ class ClientTest(TestCase):
         activity_id_found = activity['id'] if activity is not None else None
         self.assertEqual(activity['origin'], feed.id)
         self.assertEqual(activity_id_found, activity_id)
+        
+    def test_follow_and_delete(self):
+        user_feed = getfeed('user', 'test_follow')
+        agg_feed = getfeed('aggregated', 'test_follow')
+        actor_id = random.randint(10, 100000)
+        activity_data = {'actor': actor_id, 'verb': 'tweet', 'object': 1}
+        activity_id = user_feed.add_activity(activity_data)['id']
+        agg_feed.follow(user_feed.slug, user_feed.user_id)
+        time.sleep(2)
+        user_feed.remove_activity(activity_id)
+        for x in range(5):
+            activities = agg_feed.get(limit=3)['results']
+            activity = self._get_first_aggregated_activity(activities)
+            activity_id_found = activity['id'] if activity is not None else None
+            self.assertNotEqual(activity_id_found, activity_id)
+            time.sleep(1)
 
     def test_follow_private(self):
         feed = getfeed('secret', 'py1')
@@ -253,6 +269,16 @@ class ClientTest(TestCase):
         activity_id_found = activity['id'] if activity is not None else None
         self.assertEqual(activity_id_found, activity_id)
 
+    def test_flat_follow_no_copy(self):
+        feed = getfeed('user', 'test_flat_follow_no_copy')
+        follower = getfeed('flat', 'test_flat_follow_no_copy')
+        activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
+        feed.add_activity(activity_data)['id']
+        follower.follow(feed.slug, feed.user_id, activity_copy_limit=0)
+        time.sleep(10)
+        activities = follower.get(limit=3)['results']
+        self.assertEqual(activities, [])
+
     def _get_first_aggregated_activity(self, activities):
         try:
             return activities[0]['activities'][0]
@@ -388,6 +414,12 @@ class ClientTest(TestCase):
         self.assertTrue(activities[0]['is_seen'])
         self.assertTrue(activities[1]['is_seen'])
         self.assertFalse(activities[2]['is_seen'])
+        # see if the state properly resets after we add another activity
+        activity_data = {'actor': 3, 'verb': 'watch', 'object': 3}
+        activity_id_four = notification_feed.add_activity(activity_data)['id']
+        activities = notification_feed.get(limit=3)['results']
+        self.assertFalse(activities[0]['is_seen'])
+        self.assertEqual(len(activities[0]['activities']), 2)
 
     def test_mark_read_by_id(self):
         notification_feed = getfeed('notification', 'py2')
